cgexplore.terms.Bond
====================

.. currentmodule:: cgexplore.terms

.. autoclass:: Bond
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Bond.atom_names
      ~Bond.atom_ids
      ~Bond.bond_r
      ~Bond.bond_k
      ~Bond.atoms
      ~Bond.force
      ~Bond.funct
   
   